@@ -20,7 +20,7 @@
 #include "stackedwindow.h"
 #include "dailymotionvideomodel.h"
 
-class DailymotionVideoDelegate;
+class VideoDelegate;
 class ImageCache;
 class ListView;
 class QLabel;
@@ -61,7 +61,7 @@ private:
     ImageCache *m_cache;
     
     ListView *m_view;
-    DailymotionVideoDelegate *m_delegate;
+    VideoDelegate *m_delegate;
     QActionGroup *m_viewGroup;
     QAction *m_listAction;
     QAction *m_gridAction;
