@@ -48,24 +48,24 @@ YouTubeView::YouTubeView(QWidget *parent) :
     m_layout->addWidget(m_view);
     
     connect(m_view, SIGNAL(activated(QModelIndex)), this, SLOT(onItemActivated(QModelIndex)));
-    connect(YouTube::instance(), SIGNAL(commentAdded(const YouTubeComment*)),
+    connect(YouTube::instance(), SIGNAL(commentAdded(YouTubeComment*)),
             this, SLOT(onCommentAdded()));
-    connect(YouTube::instance(), SIGNAL(userSubscribed(const YouTubeUser*)),
-            this, SLOT(onUserSubscribed(const YouTubeUser*)));
-    connect(YouTube::instance(), SIGNAL(userUnsubscribed(const YouTubeUser*)),
-            this, SLOT(onUserUnsubscribed(const YouTubeUser*)));
-    connect(YouTube::instance(), SIGNAL(videoFavourited(const YouTubeVideo*)),
-            this, SLOT(onVideoFavourited(const YouTubeVideo*)));
-    connect(YouTube::instance(), SIGNAL(videoUnfavourited(const YouTubeVideo*)),
-            this, SLOT(onVideoUnfavourited(const YouTubeVideo*)));
-    connect(YouTube::instance(), SIGNAL(videoLiked(const YouTubeVideo*)),
-            this, SLOT(onVideoLiked(const YouTubeVideo*)));
-    connect(YouTube::instance(), SIGNAL(videoDisliked(const YouTubeVideo*)),
-            this, SLOT(onVideoDisliked(const YouTubeVideo*)));
-    connect(YouTube::instance(), SIGNAL(videoWatchLater(const YouTubeVideo*)),
-            this, SLOT(onVideoWatchLater(const YouTubeVideo*)));
-    connect(YouTube::instance(), SIGNAL(videoAddedToPlaylist(const YouTubeVideo*, const YouTubePlaylist*)),
-            this, SLOT(onVideoAddedToPlaylist(const YouTubeVideo*, const YouTubePlaylist*)));
+    connect(YouTube::instance(), SIGNAL(userSubscribed(YouTubeUser*)),
+            this, SLOT(onUserSubscribed(YouTubeUser*)));
+    connect(YouTube::instance(), SIGNAL(userUnsubscribed(YouTubeUser*)),
+            this, SLOT(onUserUnsubscribed(YouTubeUser*)));
+    connect(YouTube::instance(), SIGNAL(videoFavourited(YouTubeVideo*)),
+            this, SLOT(onVideoFavourited(YouTubeVideo*)));
+    connect(YouTube::instance(), SIGNAL(videoUnfavourited(YouTubeVideo*)),
+            this, SLOT(onVideoUnfavourited(YouTubeVideo*)));
+    connect(YouTube::instance(), SIGNAL(videoLiked(YouTubeVideo*)),
+            this, SLOT(onVideoLiked(YouTubeVideo*)));
+    connect(YouTube::instance(), SIGNAL(videoDisliked(YouTubeVideo*)),
+            this, SLOT(onVideoDisliked(YouTubeVideo*)));
+    connect(YouTube::instance(), SIGNAL(videoWatchLater(YouTubeVideo*)),
+            this, SLOT(onVideoWatchLater(YouTubeVideo*)));
+    connect(YouTube::instance(), SIGNAL(videoAddedToPlaylist(YouTubeVideo*, YouTubePlaylist*)),
+            this, SLOT(onVideoAddedToPlaylist(YouTubeVideo*, YouTubePlaylist*)));
 }
 
 void YouTubeView::search(const QString &query, const QString &type, const QString &order) {
@@ -184,26 +184,6 @@ void YouTubeView::showPlaylists() {
     window->show();
 }
 
-void YouTubeView::showRecommended() {
-    QString playlistId = YouTube::instance()->relatedPlaylist("recommended");
-    
-    if (playlistId.isEmpty()) {
-        QMaemo5InformationBox::information(this, tr("This channel does not have any recommended videos"));
-        return;
-    }
-    
-    QVariantMap filters;
-    filters["playlistId"] = playlistId;
-    
-    QVariantMap params;
-    params["maxResults"] = MAX_RESULTS;
-    
-    YouTubeVideosWindow *window = new YouTubeVideosWindow(StackedWindow::currentWindow());
-    window->setWindowTitle(tr("Recommended"));
-    window->list("/playlistItems", QStringList() << "snippet", filters, params);
-    window->show();
-}
-
 void YouTubeView::showSearchDialog() {
     YouTubeSearchDialog *dialog = new YouTubeSearchDialog(StackedWindow::currentWindow());
     dialog->open();
@@ -312,34 +292,34 @@ void YouTubeView::onCommentAdded() {
     QMaemo5InformationBox::information(this, tr("Your comment has been added"));
 }
 
-void YouTubeView::onUserSubscribed(const YouTubeUser *user) {
+void YouTubeView::onUserSubscribed(YouTubeUser *user) {
     QMaemo5InformationBox::information(this, tr("You have subscribed to %1").arg(user->username()));
 }
 
-void YouTubeView::onUserUnsubscribed(const YouTubeUser *user) {
+void YouTubeView::onUserUnsubscribed(YouTubeUser *user) {
     QMaemo5InformationBox::information(this, tr("You have unsubscribed to %1").arg(user->username()));
 }
 
-void YouTubeView::onVideoFavourited(const YouTubeVideo *video) {
+void YouTubeView::onVideoFavourited(YouTubeVideo *video) {
     QMaemo5InformationBox::information(this, tr("'%1' added to favourites").arg(video->title()));
 }
 
-void YouTubeView::onVideoUnfavourited(const YouTubeVideo *video) {
+void YouTubeView::onVideoUnfavourited(YouTubeVideo *video) {
     QMaemo5InformationBox::information(this, tr("'%1' removed from favourites").arg(video->title()));
 }
 
-void YouTubeView::onVideoLiked(const YouTubeVideo *video) {
+void YouTubeView::onVideoLiked(YouTubeVideo *video) {
     QMaemo5InformationBox::information(this, tr("You liked '%1'").arg(video->title()));
 }
 
-void YouTubeView::onVideoDisliked(const YouTubeVideo *video) {
+void YouTubeView::onVideoDisliked(YouTubeVideo *video) {
     QMaemo5InformationBox::information(this, tr("You disliked '%1'").arg(video->title()));
 }
 
-void YouTubeView::onVideoWatchLater(const YouTubeVideo *video) {
+void YouTubeView::onVideoWatchLater(YouTubeVideo *video) {
     QMaemo5InformationBox::information(this, tr("'%1' added to your watch later playlist").arg(video->title()));
 }
 
-void YouTubeView::onVideoAddedToPlaylist(const YouTubeVideo *video, const YouTubePlaylist *playlist) {
+void YouTubeView::onVideoAddedToPlaylist(YouTubeVideo *video, YouTubePlaylist *playlist) {
     QMaemo5InformationBox::information(this, tr("'%1' added to playlist '%2'").arg(video->title()).arg(playlist->title()));
 }
