@@ -89,7 +89,7 @@ void YouTubeComment::loadComment(const QString &id) {
 void YouTubeComment::loadComment(const QVariantMap &comment) {
     QVariantMap snippet = comment.value("snippet").toMap();
     
-    setBody(snippet.value("textDisplay").toString().toUtf8().replace("\ufeff", "").simplified());
+    setBody(snippet.value("textDisplay").toString());
     setDate(QDateTime::fromString(snippet.value("publishedAt").toString(), Qt::ISODate).toString("dd MMM yyyy"));
     setId(comment.value("id").toString());
     setParentId(snippet.value("parentId").toString());
@@ -99,7 +99,7 @@ void YouTubeComment::loadComment(const QVariantMap &comment) {
     setVideoId(snippet.value("videoId").toString());
 }
 
-void YouTubeComment::loadComment(const YouTubeComment *comment) {
+void YouTubeComment::loadComment(YouTubeComment *comment) {
     Comment::loadComment(comment);
     setParentId(comment->parentId());
 }
@@ -140,6 +140,11 @@ void YouTubeComment::addComment() {
     emit statusChanged(status());
 }
 
+void YouTubeComment::addComment(const QVariantMap &comment) {
+    loadComment(comment);
+    addComment();
+}
+
 void YouTubeComment::initRequest() {
     if (!m_request) {
         m_request = new QYouTube::ResourcesRequest(this);
